# Noggin

*noggin* is a self-service portal for FreeIPA.
The primary purpose of the portal is to allow users to sign up and manage their
account information and group membership.

The documentation is available online at https://noggin-aaa.readthedocs.io/
